@@ -9,7 +9,7 @@ from rdfhelpers.rdfhelpers import graphFrom, expandQName, URI, getvalue, setvalu
 from rdfhelpers.rdfhelpers import isContainerItemPredicate, makeContainerItemPredicate, diff
 from rdfhelpers.rdfhelpers import cbd, cbdAnalysis
 from rdfhelpers.rdfhelpers import getContainerStatements, getContainerItems, setContainerItems
-from rdfhelpers.rdfhelpers import SPARQLRepository, JournaledGraph, FocusedGraph
+from rdfhelpers.rdfhelpers import SPARQLRepository, JournaledGraph, FocusedGraph, CBDGraph
 from rdfhelpers.templated import identity, mapDict, Templated, TemplatedQueryMixin
 from rdfhelpers.constructor import Constructor
 from rdfhelpers.labels import LabelCache, SKOSLabelCache
@@ -20,7 +20,7 @@ __all__ = [
     'isContainerItemPredicate', 'makeContainerItemPredicate', 'diff',
     'cbd', 'cbdAnalysis',
     'getContainerStatements', 'getContainerItems', 'setContainerItems',
-    'SPARQLRepository', 'JournaledGraph', 'FocusedGraph',
+    'SPARQLRepository', 'JournaledGraph', 'FocusedGraph', 'CBDGraph',
     'identity', 'mapDict', 'Templated', 'TemplatedQueryMixin',
     'Constructor',
     'LabelCache', 'SKOSLabelCache',
