@@ -16,29 +16,41 @@ from rdfhelpers.templated import Templated
 # Cache the values of rdfs:label (and sub-properties thereof) for faster access. Select
 # either all vertices with a label (the default) or customize vertex selection.
 class LabelCache:
-    def __init__(self, db, label_query=None, selector=None, prepopulate=False):
+    def __init__(self, db, label_query=None, selector=None, language="en", prepopulate=False):
         self.db = db
         self.label_query = label_query or self.LABELQUERY
         self.selector = selector or "?res ?p ?o"
-        self._labels = None
-        self._search_index = None
+        self.language = language
+        self._labels = dict()
+        self._search_index = collections.defaultdict(set)
         if prepopulate:
             self.repopulate()
 
     LABELQUERY = '''
-        SELECT ?r (COALESCE(?pref_label, ?alt_label, ?other_label) AS ?label) {
+        PREFIX skos: <http://www.w3.org/2004/02/skos/core#>
+        PREFIX dc: <http://purl.org/dc/elements/1.1/>
+        SELECT ?r ?label {
             $selector
             BIND ($resource AS ?r)
+            ?label_prop rdfs:subPropertyOf* rdfs:label
             OPTIONAL { $resource skos:prefLabel ?pref_label }
             OPTIONAL { $resource skos:altLabel ?alt_label }
-            OPTIONAL { $resource dc:title|(rdfs:subPropertyOf*/rdfs:label) ?other_label }
+            OPTIONAL { $resource ?label_prop ?real_label }
+            OPTIONAL { $resource dc:title ?other_label }
+            BIND (COALESCE(?pref_label, ?alt_label, ?real_label, ?other_label) AS ?label)
+            FILTER ((str(lang(?label)) = "") || langMatches(lang(?label), "$language"))
         }
+        $limit
     '''
 
     ALLLABELSQUERY = '''
+        PREFIX skos: <http://www.w3.org/2004/02/skos/core#>
+        PREFIX dc: <http://purl.org/dc/elements/1.1/>
         SELECT DISTINCT ?label {
             $resource skos:prefLabel|skos:altLabel|dc:title|(rdfs:subPropertyOf*/rdfs:label) ?label
+            BIND (IF(langMatches(lang(?label), "$language"), 0, 1) AS ?priority)
         }
+        ORDER BY ?priority
     '''
 
     def getLabel(self, resource):
@@ -50,7 +62,8 @@ class LabelCache:
         else:
             label = None
             for res, lb in Templated.query(self.db, self.label_query,
-                                           resource=resource, selector=None):
+                                           resource=resource, selector=None, limit="LIMIT 1",
+                                           language=self.language):
                 label = lb
                 self.updateSearchIndex(resource, label)
                 break
@@ -64,14 +77,16 @@ class LabelCache:
     def repopulate(self):
         self._labels = {resource: label for resource, label
                         in Templated.query(self.db, self.label_query,
-                                           resource="?res", selector=self.selector)}
+                                           resource="?res", selector=self.selector, limit=None,
+                                           language=self.language)}
         self._search_index = collections.defaultdict(set)
         for resource, label in self._labels.items():
             self.updateSearchIndex(resource, label)
 
     def updateSearchIndex(self, resource, label):
-        for p in itertools.pairwise(label.upper()):
-            self._search_index[p[0]+p[1]].add(resource)
+        if label:
+            for p in itertools.pairwise(label.upper()):
+                self._search_index[p[0]+p[1]].add(resource)
 
     def findResources(self, substring):
         search_string = substring.upper()
@@ -91,8 +106,8 @@ class LabelCache:
     def getAllLabels(self, resource, exclude_default_namespace=True):
         if not isinstance(resource, URIRef):
             resource = URIRef(resource)
-        labels = [label for label,
-                  in Templated.query(self.db, self.ALLLABELSQUERY, resource=resource)]
+        labels = [label for label, in Templated.query(self.db, self.ALLLABELSQUERY,
+                                                      resource=resource, language=self.language)]
         qname = self.makeQName(resource)
         if qname == str(resource):
             return labels + [qname]
@@ -102,7 +117,10 @@ class LabelCache:
             return labels + [qname, str(resource)]
 
     def makeQName(self, uri):
-        return "{0}:{2}".format(*self.db.namespace_manager.compute_qname(uri))
+        try:
+            return "{0}:{2}".format(*self.db.namespace_manager.compute_qname(uri))
+        except ValueError:
+            return str(uri)
 
 # SKOS CONCEPT LABEL CACHING
 #
